==> gax-0.11.0-sources.jar: com/google/api/gax/retrying/RetryingFuture.java <==
/*
 * Copyright 2017, Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.google.api.gax.retrying;

import com.google.api.gax.core.ApiFuture;
import java.util.concurrent.Callable;

/**
 * Represents a retrying future. This is a facade hiding all the complications of an asynchronous
 * execution of a retriable task.
 *
 * This interface is for advanced/internal use only.
 *
 * @param <ResponseT> response type
 */
public interface RetryingFuture<ResponseT> extends ApiFuture<ResponseT> {

  /**
   * Sets the attempt future. This future represents a concrete retry attempt, potentially scheduled
   * for execution in a some form of {@link java.util.concurrent.ScheduledExecutorService}.
   *
   * @param attemptFuture the attempt future
   */
  void setAttemptFuture(ApiFuture<ResponseT> attemptFuture);

  /** Returns current (active) attempt settings. */
  TimedAttemptSettings getAttemptSettings();

  /**
   * Returns callable tracked by this future.
   */
  Callable<ResponseT> getCallable();
}

==> gax-0.12.0-sources.jar: com/google/api/gax/retrying/RetryingFuture.java <==
/*
 * Copyright 2017, Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.google.api.gax.retrying;

import com.google.api.core.ApiFuture;
import java.util.concurrent.Callable;

/**
 * Represents a retrying future. This is a facade hiding all the complications of an asynchronous
 * execution of a retriable task.
 *
 * This interface is for advanced/internal use only.
 *
 * @param <ResponseT> response type
 */
public interface RetryingFuture<ResponseT> extends ApiFuture<ResponseT> {

  /**
   * Sets the attempt future. This future represents a concrete retry attempt, potentially scheduled
   * for execution in a some form of {@link java.util.concurrent.ScheduledExecutorService}.
   *
   * @param attemptFuture the attempt future
   */
  void setAttemptFuture(ApiFuture<ResponseT> attemptFuture);

  /** Returns current (active) attempt settings. */
  TimedAttemptSettings getAttemptSettings();

  /**
   * Returns callable tracked by this future.
   */
  Callable<ResponseT> getCallable();
}
